@@ -45,9 +45,7 @@
 #endif
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#ifdef HAVE_CAM
-  #include "../libcamera/camera.h"
-#endif
+#include "../libcamera/camera.h"
 #include "userlist.h"
 #include "media.h"
 #include "compat.h"
@@ -407,7 +405,7 @@ gboolean handledata(GIOChannel* iochannel, GIOCondition condition, gpointer data
     return 1;
   }
   // Start a stream when someone cams up
-  if(space && !strcmp(space, " cammed up"))
+  if(space && !strcmp(space, " cammed up") && (config_get_bool("autoopencams") || !config_get_set("autoopencams")))
   {
     space[0]=0;
     dprintf(tc_client_in[1], "/opencam %s\n", buf);
@@ -599,7 +597,6 @@ void audiothread(int fd)
 }
 #endif
 
-#ifdef HAVE_CAM
 unsigned int cameventsource=0;
 void togglecam(GtkCheckMenuItem* item, struct viddata* data)
 {
@@ -623,7 +620,6 @@ void togglecam(GtkCheckMenuItem* item, struct viddata* data)
   GIOChannel* channel=camthread(gtk_combo_box_get_active_id(combo), data->vencoder, 100000);
   cameventsource=g_io_add_watch(channel, G_IO_IN, handledata, 0);
 }
-#endif
 
 gboolean handleresize(GtkWidget* widget, GdkEventConfigure* event, struct viddata* data)
 {
@@ -818,19 +814,6 @@ void startsession(GtkButton* button, void* x)
   const char* acc_user=gtk_entry_get_text(GTK_ENTRY(gtk_builder_get_object(gui, "acc_username")));
   const char* acc_pass=gtk_entry_get_text(GTK_ENTRY(gtk_builder_get_object(gui, "acc_password")));
 #ifdef _WIN32
-  HANDLE h_tc_client0, h_tc_client1;
-  CreatePipe(&h_tc_client0, &h_tc_client1, &sa, 0);
-  HANDLE h_tc_client_in0, h_tc_client_in1;
-  CreatePipe(&h_tc_client_in0, &h_tc_client_in1, &sa, 0);
-  tc_client[0]=_open_osfhandle(h_tc_client0, _O_RDONLY);
-  tc_client[1]=_open_osfhandle(h_tc_client1, _O_WRONLY);
-  tc_client_in[0]=_open_osfhandle(h_tc_client_in0, _O_RDONLY);
-  tc_client_in[1]=_open_osfhandle(h_tc_client_in1, _O_WRONLY);
-  STARTUPINFO startup;
-  GetStartupInfo(&startup);
-  startup.dwFlags|=STARTF_USESTDHANDLES;
-  startup.hStdInput=h_tc_client_in0;
-  startup.hStdOutput=h_tc_client1;
   char cmd[strlen("./tc_client -u    0")+strlen(acc_user)+strlen(channel)+strlen(nick)+strlen(chanpass)];
   strcpy(cmd, "./tc_client ");
   if(acc_user[0])
@@ -845,7 +828,7 @@ void startsession(GtkButton* button, void* x)
   strcat(cmd, " ");
   strcat(cmd, chanpass);
   strcat(cmd, " ");
-  CreateProcess(0, cmd, 0, 0, 1, DETACHED_PROCESS, 0, 0, &startup, &coreprocess);
+  w32_runcmdpipes(cmd, tc_client_in, tc_client, coreprocess);
 #else
   pipe(tc_client);
   pipe(tc_client_in);
@@ -929,7 +912,6 @@ int main(int argc, char** argv)
   gtk_builder_connect_signals(gui, 0);
 
   unsigned int i;
-#ifdef HAVE_CAM
   GtkWidget* item=GTK_WIDGET(gtk_builder_get_object(gui, "menuitem_broadcast_camera"));
   g_signal_connect(item, "toggled", G_CALLBACK(togglecam), data);
   data->vencoder=avcodec_find_encoder(AV_CODEC_ID_FLV1);
@@ -949,6 +931,8 @@ int main(int argc, char** argv)
   // Signals for switching from preview to streaming
   item=GTK_WIDGET(gtk_builder_get_object(gui, "camselect_ok"));
   g_signal_connect(item, "clicked", G_CALLBACK(camselect_accept), data->vencoder);
+  // Enable the "img" camera
+  cam_img_filepicker=camselect_file;
   // Populate list of cams
   unsigned int count;
   char** cams=cam_list(&count);
@@ -962,10 +946,6 @@ int main(int argc, char** argv)
   gtk_combo_box_set_model(combo, GTK_TREE_MODEL(list));
   g_object_unref(list);
   gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo), gtk_cell_renderer_text_new(), 1);
-#else
-  GtkWidget* item=GTK_WIDGET(gtk_builder_get_object(gui, "menuitem_broadcast"));
-  gtk_widget_destroy(item);
-#endif
 
   item=GTK_WIDGET(gtk_builder_get_object(gui, "menuitem_options_settings"));
   g_signal_connect(item, "activate", G_CALLBACK(showsettings), gui);
@@ -1062,6 +1042,10 @@ int main(int argc, char** argv)
   {
     TerminateProcess(coreprocess.hProcess, 0);
   }
+  if(camproc)
+  {
+    TerminateProcess(camproc, 0);
+  }
 #endif
   camera_cleanup();
 #ifdef HAVE_AVRESAMPLE
