@@ -20,6 +20,11 @@ struct user
   GtkWidget* label;
 //  unsigned int id; // hm, tc_client doesn't share IDs other than in guestnicks, this might be useful for a ban-after-they-left situation
   char ismod;
+  GtkWidget* pm_tab;
+  GtkWidget* pm_tablabel;
+  GtkTextBuffer* pm_buffer;
+  GtkAdjustment* pm_scroll;
+  char pm_highlight;
 };
 
 extern struct user* userlist;
@@ -27,6 +32,7 @@ extern unsigned int usercount;
 extern GtkWidget* userlistwidget;
 
 extern struct user* finduser(const char* nick);
+extern struct user* user_find_by_tab(GtkWidget* tab);
 extern struct user* adduser(const char* nick);
 extern void renameuser(const char* old, const char* newnick);
 extern void removeuser(const char* nick);
